==> zio-aws-groundstation_2.12-5.20.37.1-sources.jar: zio/aws/groundstation/model/Destination.scala <==
package zio.aws.groundstation.model
import zio.aws.groundstation.model.primitives.Uuid
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class Destination(
    configDetails: Optional[zio.aws.groundstation.model.ConfigDetails] =
      Optional.Absent,
    configId: Optional[Uuid] = Optional.Absent,
    configType: Optional[zio.aws.groundstation.model.ConfigCapabilityType] =
      Optional.Absent,
    dataflowDestinationRegion: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.Destination = {
    import Destination.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.Destination
      .builder()
      .optionallyWith(configDetails.map(value => value.buildAwsValue()))(
        _.configDetails
      )
      .optionallyWith(
        configId.map(value => Uuid.unwrap(value): java.lang.String)
      )(_.configId)
      .optionallyWith(configType.map(value => value.unwrap))(_.configType)
      .optionallyWith(
        dataflowDestinationRegion.map(value => value: java.lang.String)
      )(_.dataflowDestinationRegion)
      .build()
  }
  def asReadOnly: zio.aws.groundstation.model.Destination.ReadOnly =
    zio.aws.groundstation.model.Destination.wrap(buildAwsValue())
}
object Destination {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.Destination
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.Destination =
      zio.aws.groundstation.model.Destination(
        configDetails.map(value => value.asEditable),
        configId.map(value => value),
        configType.map(value => value),
        dataflowDestinationRegion.map(value => value)
      )
    def configDetails
        : Optional[zio.aws.groundstation.model.ConfigDetails.ReadOnly]
    def configId: Optional[Uuid]
    def configType: Optional[zio.aws.groundstation.model.ConfigCapabilityType]
    def dataflowDestinationRegion: Optional[String]
    def getConfigDetails: ZIO[
      Any,
      AwsError,
      zio.aws.groundstation.model.ConfigDetails.ReadOnly
    ] = AwsError.unwrapOptionField("configDetails", configDetails)
    def getConfigId: ZIO[Any, AwsError, Uuid] =
      AwsError.unwrapOptionField("configId", configId)
    def getConfigType
        : ZIO[Any, AwsError, zio.aws.groundstation.model.ConfigCapabilityType] =
      AwsError.unwrapOptionField("configType", configType)
    def getDataflowDestinationRegion: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("dataflowDestinationRegion", dataflowDestinationRegion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.Destination
  ) extends zio.aws.groundstation.model.Destination.ReadOnly {
    override val configDetails
        : Optional[zio.aws.groundstation.model.ConfigDetails.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.configDetails())
        .map(value => zio.aws.groundstation.model.ConfigDetails.wrap(value))
    override val configId: Optional[Uuid] = zio.aws.core.internal
      .optionalFromNullable(impl.configId())
      .map(value => zio.aws.groundstation.model.primitives.Uuid(value))
    override val configType
        : Optional[zio.aws.groundstation.model.ConfigCapabilityType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.configType())
        .map(value =>
          zio.aws.groundstation.model.ConfigCapabilityType.wrap(value)
        )
    override val dataflowDestinationRegion: Optional[String] =
      zio.aws.core.internal
        .optionalFromNullable(impl.dataflowDestinationRegion())
        .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.Destination
  ): zio.aws.groundstation.model.Destination.ReadOnly = new Wrapper(impl)
}

==> zio-aws-groundstation_3-5.17.103.1-sources.jar: zio/aws/groundstation/model/Destination.scala <==
package zio.aws.groundstation.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class Destination(
    configDetails: Option[zio.aws.groundstation.model.ConfigDetails] = None,
    configId: Option[String] = None,
    configType: Option[zio.aws.groundstation.model.ConfigCapabilityType] = None,
    dataflowDestinationRegion: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.groundstation.model.Destination = {
    import Destination.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.groundstation.model.Destination
      .builder()
      .optionallyWith(configDetails.map(value => value.buildAwsValue()))(
        _.configDetails
      )
      .optionallyWith(configId.map(value => value: java.lang.String))(
        _.configId
      )
      .optionallyWith(configType.map(value => value.unwrap))(_.configType)
      .optionallyWith(
        dataflowDestinationRegion.map(value => value: java.lang.String)
      )(_.dataflowDestinationRegion)
      .build()
  }
  def asReadOnly: zio.aws.groundstation.model.Destination.ReadOnly =
    zio.aws.groundstation.model.Destination.wrap(buildAwsValue())
}
object Destination {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.groundstation.model.Destination
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.groundstation.model.Destination =
      zio.aws.groundstation.model.Destination(
        configDetails.map(value => value.asEditable),
        configId.map(value => value),
        configType.map(value => value),
        dataflowDestinationRegion.map(value => value)
      )
    def configDetails
        : Option[zio.aws.groundstation.model.ConfigDetails.ReadOnly]
    def configId: Option[String]
    def configType: Option[zio.aws.groundstation.model.ConfigCapabilityType]
    def dataflowDestinationRegion: Option[String]
    def getConfigDetails: ZIO[
      Any,
      AwsError,
      zio.aws.groundstation.model.ConfigDetails.ReadOnly
    ] = AwsError.unwrapOptionField("configDetails", configDetails)
    def getConfigId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("configId", configId)
    def getConfigType
        : ZIO[Any, AwsError, zio.aws.groundstation.model.ConfigCapabilityType] =
      AwsError.unwrapOptionField("configType", configType)
    def getDataflowDestinationRegion: ZIO[Any, AwsError, String] = AwsError
      .unwrapOptionField("dataflowDestinationRegion", dataflowDestinationRegion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.groundstation.model.Destination
  ) extends zio.aws.groundstation.model.Destination.ReadOnly {
    override val configDetails
        : Option[zio.aws.groundstation.model.ConfigDetails.ReadOnly] = scala
      .Option(impl.configDetails())
      .map(value => zio.aws.groundstation.model.ConfigDetails.wrap(value))
    override val configId: Option[String] =
      scala.Option(impl.configId()).map(value => value: String)
    override val configType
        : Option[zio.aws.groundstation.model.ConfigCapabilityType] = scala
      .Option(impl.configType())
      .map(value =>
        zio.aws.groundstation.model.ConfigCapabilityType.wrap(value)
      )
    override val dataflowDestinationRegion: Option[String] =
      scala.Option(impl.dataflowDestinationRegion()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.groundstation.model.Destination
  ): zio.aws.groundstation.model.Destination.ReadOnly = new Wrapper(impl)
}
